#!/usr/bin/env python

"Configuration settings for imiptools programs."

# The public identity of the agent.

MESSAGE_SENDER = "calendar@example.com"

# The local message handling prefix.

LOCAL_PREFIX = "local"

# The outgoing message handling prefix.

OUTGOING_PREFIX = "people-outgoing"

# The location of the stored calendar information.

STORE_DIR = "/var/lib/imip-agent/store"

# The location of published static free/busy information.

PUBLISH_DIR = "/var/www/imip-agent/static"

# The location of user preferences information.

PREFERENCES_DIR = "/var/lib/imip-agent/preferences"

# Permissions for files.
# This is meant to ensure that both the agent and Web users can access files.

DEFAULT_PERMISSIONS = 0660

# Permissions for directories.
# This is meant to ensure that the group is set for files.

DEFAULT_DIR_PERMISSIONS = 02770

# Internationalisation and translations support.

LOCALE_DIR = "/usr/share/locale"
TRANS_DOMAIN = "imip-agent"



# The availability of a management interface for calendar information.
# True: provide links in notifications to the interface described below.
# False: omit links in notifications.

MANAGER_INTERFACE = True

# The published location of the manager application.
# This must match any Web site configuration details for the manager.

MANAGER_PATH = "/imip-manager"

# The full URL of the manager application excluding the above path.
# If set to None, the details of this machine will be employed.

MANAGER_URL = None

# The protocol scheme used if constructing URLs.

MANAGER_URL_SCHEME = "http://"



# Preferences defaults applicable unless overridden by the user.
# Changing these allows organisational policy to be defined while still
# allowing users to choose more appropriate settings themselves.
# See: docs/preferences.txt

# Default language for messages.

LANG = "en"

# Do users participate in the calendar system by default?

PARTICIPATING_DEFAULT = "participate"

# How should incoming messages be presented to a user by default?

INCOMING_DEFAULT = "summary-wraps-message"

# Do users share free/busy information by default? This affects the bundling and
# publishing settings.

SHARING_DEFAULT = "no"

# Are free/busy details published on the Web by default?

PUBLISHING_DEFAULT = "no"

# Are free/busy details bundled with other objects in messages by default?

BUNDLING_DEFAULT = "never"

# What notifications do users get about incoming free/busy messages by default?

NOTIFYING_DEFAULT = "none"

# Are REFRESH messages automatically handled by default?

REFRESHING_DEFAULT = "never"

# How are ADD messages responded to by default?

ADD_RESPONSE_DEFAULT = "refresh"

# Who can replace an organiser in an event by default?

ORGANISER_REPLACEMENT_DEFAULT = "attendee"

# How long are free/busy offers valid for by default?
# (None means that no offers are maintained for counter-proposals and thus any
# periods in the counter-proposal are not held in anticipation of a response.)

FREEBUSY_OFFER_DEFAULT = None



# Policy settings.

# Allow mislabelled iMIP Content-Type method parameter values for COUNTER
# messages (seen in Kontact).

IMIP_COUNTER_AS_REQUEST = True

# vim: tabstop=4 expandtab shiftwidth=4
